@@ -1,11 +1,11 @@
 from datetime import datetime
 from inspect import cleandoc
 from json import dumps
+from json import load
 from os import environ
-from os.path import abspath
 from os.path import getsize
-from os.path import isfile
 from os.path import join
+from os.path import split
 from re import match
 from sys import stderr
 from typing import Callable
@@ -14,13 +14,16 @@ from typing import Union
 
 from faapi import __version__ as __faapi_version__
 from falocalrepo_database import FADatabase
+from falocalrepo_database import FADatabaseCursor
+from falocalrepo_database import FADatabaseTable
 from falocalrepo_database import __version__ as __database_version__
 from falocalrepo_server import __version__ as __server_version__
 from falocalrepo_server import server
+from psutil import AccessDenied
+from psutil import NoSuchProcess
+from psutil import process_iter
 
 from .__version__ import __version__
-from .commands import check_database
-from .commands import check_process
 from .commands import latest_version
 from .commands import make_journal
 from .commands import make_submission
@@ -34,8 +37,6 @@ from .download import download_submissions as download_submissions_
 from .download import download_users as download_users_
 from .download import download_users_update
 from .download import read_cookies
-from .download import save_journal
-from .download import save_submission
 from .download import write_cookies
 
 
@@ -51,6 +52,31 @@ class MultipleInstances(Exception):
     pass
 
 
+def check_process(process: str):
+    ps: int = 0
+    for p in process_iter():
+        try:
+            ps += "python" in p.name().lower() and any(process in split(cmd) for cmd in p.cmdline())
+        except (NoSuchProcess, AccessDenied):
+            pass
+        if ps > 1:
+            raise MultipleInstances(f"Another instance of {process} was detected")
+
+
+def check_database_version(db: FADatabase, raise_for_error: bool = True):
+    if (err := db.check_version(raise_for_error=False)) is not None:
+        print(f"Database version is not latest: {db.version} != {__database_version__}")
+        print("Use database upgrade command to upgrade database")
+        if raise_for_error:
+            raise err
+
+
+def check_database_connections(db: FADatabase):
+    if len(db.check_connection(raise_for_error=False)) > 1:
+        db.close()
+        raise MultipleInstances(f"Another connection to {db.database_path} was detected")
+
+
 def raiser(e: Exception) -> Callable:
     def inner(*_):
         raise e
@@ -112,12 +138,9 @@ def help_(comm: str = "", op: str = "", *_rest) -> str:
         <command>       Command to get the help of
         <operation>     Command operation to get the help of
 
-    AVAILABLE COMMANDS
-        help            Display the manual of help
-        init            Display the manual of init
-        config          Display the manual of config
-        download        Display the manual of download
-        database        Display the manual of database
+    DESCRIPTION
+        Get help for a specific command or operation. If no command is passed
+        then a general help message is given instead.
     """
 
     f = {
@@ -147,6 +170,7 @@ def help_(comm: str = "", op: str = "", *_rest) -> str:
         "database remove-journals": database_remove_journals,
         "database server": database_server,
         "database merge": database_merge,
+        "database copy": database_copy,
         "database clean": database_clean,
         "database upgrade": database_upgrade,
     }.get(comm := f"{comm} {op}".strip(), None)
@@ -163,14 +187,12 @@ def init(db: FADatabase):
         falocalrepo init
 
     DESCRIPTION
-        The init command initialises the database or, if one is already present,
-        updates to a new version - if available - and then exits.
-
-        It can be used to create the database and then manually edit it, or to
-        update it to a new version without calling other commands.
+        The init command initialises the database and then exits. It can be used to
+        create the database without performing any other operation. If a database is
+        already present, no operation is performed.
     """
 
-    check_database(db.version, __database_version__)
+    check_database_version(db)
     print("Database ready")
 
 
@@ -191,12 +213,11 @@ def config_list(db: FADatabase, *_rest):
 def config_cookies(db: FADatabase, *args: str):
     """
     USAGE
-        falocalrepo config cookies [<cookie1 name>=<cookie1 value>] ...
-                    [<cookieN name>=<cookieN value>]
+        falocalrepo config cookies [<name1>=<value1> ... <nameN>=<valueN>]
 
     ARGUMENTS
-        <cookie name>   The name of the cookie (e.g. a)
-        <cookie value>  The value of the cookie
+        <name>   The name of the cookie (e.g. a)
+        <value>  The value of the cookie
 
     DESCRIPTION
         Read or modify stored cookies.
@@ -255,13 +276,13 @@ def config(db: FADatabase, comm: str = "", *args: str):
         The config command allows to change the settings used by the program.
     """
 
-    check_database(db.version, __database_version__)
+    check_database_version(db)
 
     {
         "": config_list,
         "list": config_list,
         "cookies": config_cookies,
-        "files_folder": config_files_folder,
+        "files-folder": config_files_folder,
     }.get(comm, raiser(UnknownCommand(f"config {comm}")))(db, *args)
 
 
@@ -285,7 +306,7 @@ def download_users(db: FADatabase, *args: str):
 
     EXAMPLES
         falocalrepo download users tom,jerry gallery,scraps,journals
-        falocalrepo download users tom,jerry list-favorites
+        falocalrepo download users tom list-favorites
     """
 
     if len(args) != 2:
@@ -302,7 +323,7 @@ def download_update(db: FADatabase, *args: str):
     """
     USAGE
         falocalrepo download update [stop=<stop n>] [deactivated=<deactivated>]
-                    [<user1>,...,<userN>] [<folder1>,...,<folderN>]
+                    [<user1>,...,<userN> | @] [<folder1>,...,<folderN> | @]
 
     ARGUMENTS
         <stop n>       Number of submissions to find in database before stopping,
@@ -315,13 +336,14 @@ def download_update(db: FADatabase, *args: str):
     DESCRIPTION
         Update the repository by checking the previously downloaded folders
         (gallery, scraps, favorites or journals) of each user and stopping when it
-        finds a submission that is already present in the repository. Can pass a
-        list of users and/or folders that will be updated if in the database. To
-        skip users, use '@' as argument. The 'stop=<n>' option allows to stop
-        updating after finding n submissions in a user's database entry, defaults
-        to 1. If a user is deactivated, the folders in the database will be
-        prepended with a '!'. Deactivated users will be skipped when update is
-        called, unless the '<deactivated>' option is set to 'true'.
+        finds a submission that is already present in the database. If a list of
+        users and/or folders is passed, the update will be limited to those. To
+        limit the update to certain folders without skipping any user, use '@' in
+        place of the users argument. The stop=<n> option allows to stop updating
+        after finding n submissions in a user's database entry, defaults to 1. If a
+        user is deactivated, the folders in the database will be prepended with a
+        '!'. Deactivated users will be skipped during the update unless the
+        <deactivated> option is set to 'true'.
 
     EXAMPLES
         falocalrepo download update stop=5
@@ -405,12 +427,13 @@ def download(db: FADatabase, comm: str = "", *args: str):
         journals        Download single journals
 
     DESCRIPTION
-        The download command performs all download operations get and update users,
-        submissions, and journals. Submissions are downloaded together with their
-        thumbnails, if there are any.
+        The download command performs all download operations to save and update
+        users, submissions, and journals. Submissions are downloaded together with
+        their thumbnails, if there are any.
     """
 
-    check_database(db.version, __database_version__)
+    check_database_version(db)
+    check_process("falocalrepo")
 
     {
         "": raiser(MalformedCommand("download needs a command")),
@@ -451,10 +474,10 @@ def database_history(db: FADatabase):
         print(str(datetime.fromtimestamp(time)), command)
 
 
-def database_search_users(db: FADatabase, *args: str):
+def database_search(table: FADatabaseTable, print_func: Callable, *args: str):
     """
     USAGE
-        falocalrepo database search-users [json=<json>] [columns=<columns>]
+        falocalrepo database search-{0} [json=<json>] [columns=<columns>]
                     [<param1>=<value1>] ... [<paramN>=<valueN>]
 
     ARGUMENTS
@@ -464,49 +487,41 @@ def database_search_users(db: FADatabase, *args: str):
         <value>     Value of the parameter
 
     DESCRIPTION
-        Search the users entries using metadata fields. Search parameters can be
-        passed multiple times to act as OR values. All columns of the users table
-        are supported. Parameters can be lowercase. If no parameters are supplied, a
-        list of all users will be returned instead. If <json> is set to 'true', the
-        results are printed as a list of objects in JSON format. If <columns> is
-        passed, then the objects printed with the JSON option will only contain
-        those fields.
-
-    EXAMPLES
-        falocalrepo database search-users json=true \\
-            folders=%gallery% gallery=%0012345678%
+        Search the {0} entries using metadata fields. Search parameters can
+        be passed multiple times to act as OR values. All columns of the {0}
+        table are supported. Parameters can be lowercase. If no parameters are
+        supplied, a list of all {0} will be returned instead. If <json> is
+        set to 'true', the results are printed as a list of objects in JSON format.
+        If <columns> is passed, then the objects printed with the JSON option will
+        only contain those fields.
     """
 
     opts = parameters_multi(args)
     json, cols = opts.get("json", [None])[0] == "true", opts["columns"][0].split(",") if "columns" in opts else None
-    results: list[dict[str, Union[int, str]]] = search(db.users, opts, cols if cols and json else None)
+    results: list[dict[str, Union[int, str]]] = search(table, opts, cols if cols and json else None)
     if json:
         print(dumps(results))
     else:
-        print_users(results)
+        print_func(results)
         print(f"Found {len(results)} users")
 
 
+@docstring_parameter(database_search.__doc__.format("users"))
+def database_search_users(db: FADatabase, *args: str):
+    """
+    {0}
+
+    EXAMPLES
+        falocalrepo database search-users json=true folders=%gallery%
+    """
+
+    database_search(db.users, print_users, *args)
+
+
+@docstring_parameter(database_search.__doc__.format("submissions"))
 def database_search_submissions(db: FADatabase, *args: str):
     """
-    USAGE
-        falocalrepo database search-submissions [json=<json>] [columns=<columns>]
-                    [<param1>=<value1>] ... [<paramN>=<valueN>]
-
-    ARGUMENTS
-        <json>      Set to 'true' to output metadata in JSON format
-        <columns>   Comma-separated list of columns to select, only active for JSON
-        <param>     Search parameter
-        <value>     Value of the parameter
-
-    DESCRIPTION
-        Search the submissions entries using metadata fields. Search parameters can
-        be passed multiple times to act as OR values. All columns of the submissions
-        table are supported. Parameters can be lowercase. If no parameters are
-        supplied, a list of all submissions will be returned instead. If <json> is
-        set to 'true', the results are printed as a list of objects in JSON format.
-        If <columns> is passed, then the objects printed with the JSON option will
-        only contain those fields.
+    {0}
 
     EXAMPLES
         falocalrepo database search-submissions tags=%|cat|%|mouse|% date=2020-% \\
@@ -515,36 +530,13 @@ def database_search_submissions(db: FADatabase, *args: str):
             tags=%|cat|% tags=%|mouse|% date=2020-% category=%artwork%
     """
 
-    opts = parameters_multi(args)
-    json, cols = opts.get("json", [None])[0] == "true", opts["columns"][0].split(",") if "columns" in opts else None
-    results: list[dict[str, Union[int, str]]] = search(db.submissions, opts, cols if cols and json else None)
-    if json:
-        print(dumps(results))
-    else:
-        print_items(results)
-        print(f"Found {len(results)} results")
+    database_search(db.submissions, print_items, *args)
 
 
+@docstring_parameter(database_search.__doc__.format("journals"))
 def database_search_journals(db: FADatabase, *args: str):
     """
-    USAGE
-        falocalrepo database search-journals [json=<json>] [columns=<columns>]
-                    [<param1>=<value1>] ... [<paramN>=<valueN>]
-
-    ARGUMENTS
-        <json>      Set to 'true' to output metadata in JSON format
-        <columns>   Comma-separated list of columns to select, only active for JSON
-        <param>     Search parameter
-        <value>     Value of the parameter
-
-    DESCRIPTION
-        Search the journals entries using metadata fields. Search parameters can
-        be passed multiple times to act as OR values. All columns of the journals
-        table are supported. Parameters can be lowercase. If no parameters are
-        supplied, a list of all submissions will be returned instead. If <json> is set
-        to 'true', the results are printed as a list of objects in JSON format. If
-        <columns> is passed, then the objects printed with the JSON option will only
-        contain those fields.
+    {0}
 
     EXAMPLES
         falocalrepo database search-journals date=2020-% author=CatArtist \\
@@ -553,35 +545,28 @@ def database_search_journals(db: FADatabase, *args: str):
             date=2020-% date=2019-% content=%commission%
     """
 
-    opts = parameters_multi(args)
-    json, cols = opts.get("json", [None])[0] == "true", opts["columns"][0].split(",") if "columns" in opts else None
-    results: list[dict[str, Union[int, str]]] = search(db.journals, opts, cols if cols and json else None)
-    if json:
-        print(dumps(results))
-    else:
-        print_items(results)
-        print(f"Found {len(results)} results")
+    database_search(db.journals, print_items, *args)
 
 
 def database_add_user(db: FADatabase, *args):
     """
     USAGE
-        falocalrepo database add-user <param1>=<value1> ... <paramN>=<valueN>
+        falocalrepo database add-user <json>
 
     ARGUMENTS
-        <param>     Make parameter
-        <value>     Value of the parameter
+        <json>  Path to a JSON file containing the user metadata
 
     DESCRIPTION
-        Add a user to the database manually. If the user is already present, the
-        folders parameter will overwrite the existing value if given. The following
-        parameters are necessary for a user entry to be accepted:
+        Add or replace a user entry into the database using metadata from a JSON
+        file. If the user already exists in the database, fields may be omitted from
+        the JSON, except for the ID. Omitted fields will not be replaced in the
+        database and will remain as they are. The following fields are supported:
             * 'username'
-        The following parameters are optional:
+        The following fields are optional:
             * 'folders'
 
     EXAMPLES
-        falocalrepo database add-user username=tom folders=gallery,scraps
+        falocalrepo database add-user ./user.json
     """
 
     make_params: dict[str, str] = parameters(args)
@@ -599,82 +584,79 @@ def database_add_user(db: FADatabase, *args):
 def database_add_submission(db: FADatabase, *args: str):
     """
     USAGE
-        falocalrepo database add-submissions <param1>=<value1> ... <paramN>=<valueN>
+        falocalrepo database add-submissions <json> [file=<file>] [thumb=<thumb>]
 
     ARGUMENTS
-        <param>     Make parameter
-        <value>     Value of the parameter
+        <json>  Path to a JSON file containing the submission metadata
+        <file>  Path to new file
+        <thumb> Path to new thumbnail
 
     DESCRIPTION
-        Add a submission to the database manually. The submission file is not
-        downloaded and can instead be provided with the extra parameter
-        'file_local_url'. The following parameters are necessary for a submission
-        entry to be accepted:
+        Add or replace a submission entry into the database using metadata from a
+        JSON file. If the submission already exists in the database, fields may be
+        omitted from the JSON, except for the ID. Omitted fields will not be
+        replaced in the database and will remain as they are. The optional <file>
+        and <thumb> parameters allow to add or replace the submission file and
+        thumbnail respectively. The following fields are supported:
             * 'id'
             * 'title'
             * 'author'
             * 'date' date in the format YYYY-MM-DD
+            * 'description'
             * 'category'
             * 'species'
             * 'gender'
             * 'rating'
             * 'type' image, text, music, or flash
             * 'folder' gallery or scraps
-        The following parameters are optional:
-            * 'tags' comma-separated tags
-            * 'description'
-            * 'file_url' the url of the submission file
-            * 'file_local_url' if provided, take the submission file from this path
-                and put it into the database
+            * 'fileurl' the remote URL of the submission file
+        The following fields are optional:
+            * 'tags' list of tags, if omitted it defaults to existing entry or empty
+            * 'favorite' list of users that faved the submission, if omitted it
+                defaults to existing entry or empty
+            * 'mentions' list of mentioned users, if omitted it defaults to existing
+                entry or mentions are extracted from the description
+            * 'userupdate' 1 if the submission is downloaded as part of a user
+                gallery/scraps else 0, if omitted it defaults to entry or 0
 
     EXAMPLES
-        falocalrepo database add-submission id=12345678 title='cat & mouse' \\
-            author=CartoonArtist date=2020-08-09 category=Artwork \\
-            species='Unspecified / Any' gender=Any rating=General type=image \\
-            tags=cat,mouse,cartoon description="$(cat description.html)" \\
-            file_url='http://remote.url/to/submission.file' \\
-            file_local_url='path/to/submission.file' folder=gallery
+        falocalrepo database add-submission ./submission/metadata.json \\
+            file=./submission/submission.pdf thumb=./submission/thumbnail.jpg
     """
 
-    make_params = parameters(args)
-    make_params["id_"] = make_params.get("id", "")
-    make_params["type_"] = make_params.get("type", "")
-    if "id" in make_params:
-        del make_params["id"]
-    if "type" in make_params:
-        del make_params["type_"]
-    save_submission(db, *make_submission(**make_params), user_update=False)
+    data: dict = load(open(args[0]))
+    opts: dict = parameters(args[1:])
+    make_submission(db, data, opts.get("file", None), opts.get("thumbnail", None))
 
 
 def database_add_journal(db: FADatabase, *args: str):
     """
     USAGE
-        falocalrepo database add-journal <param1>=<value1> ... <paramN>=<valueN>
+        falocalrepo database add-journal <json>
 
     ARGUMENTS
-        <param>     Make parameter
-        <value>     Value of the parameter
+        <json>  Path to a JSON file containing the journal metadata
 
     DESCRIPTION
-        Add a journal to the database manually. The following parameters are
-        necessary for a journal entry to be accepted:
+        Add or replace a journal entry into the database using metadata from a JSON
+        file. If the journal already exists in the database, fields may be omitted
+        from the JSON, except for the ID. Omitted fields will not be replaced in the
+        database and will remain as they are. The following fields are supported:
             * 'id'
             * 'title'
             * 'author'
             * 'date' date in the format YYYY-MM-DD
-        The following parameters are optional:
             * 'content' the body of the journal
+        The following fields are optional:
+             * 'mentions' list of mentioned users, if omitted it defaults to existing
+                entry or mentions are extracted from the content
 
     EXAMPLES
-        falocalrepo database add-journal id=12345678 title="An Update" \\
-            author=CartoonArtist date=2020-08-09 content="$(cat journal.html)"
+        falocalrepo database add-journal ./journal.json"
     """
 
-    make_params = parameters(args)
-    make_params["id_"] = make_params.get("id", "")
-    if "id" in make_params:
-        del make_params["id"]
-    save_journal(db, make_journal(**make_params), user_update=False)
+    data: dict = load(open(args[0]))
+    make_journal(db, data)
 
 
 def database_remove_users(db: FADatabase, *args: str):
@@ -731,7 +713,7 @@ def database_remove_journals(db: FADatabase, *args: str):
     db.commit()
 
 
-@docstring_parameter(f"https://pypi.org/project/falocalrepo-server/{__server_version__}")
+@docstring_parameter(__server_version__)
 def database_server(db: FADatabase, *args: str):
     """
     USAGE
@@ -744,7 +726,7 @@ def database_server(db: FADatabase, *args: str):
     DESCRIPTION
         Starts a server at <host>:<port> to navigate the database, defaults to
         0.0.0.0:8080. For more details on usage see
-        {0}.
+        https://pypi.org/project/falocalrepo-server/{0}.
 
     EXAMPLES
         falocalrepo database server host=127.0.0.1 port=5000
@@ -755,31 +737,88 @@ def database_server(db: FADatabase, *args: str):
     print()
 
 
+def database_merge_copy(db: FADatabase, merge: bool = True, *args):
+    if not args:
+        raise MalformedCommand("copy needs at least a database argument")
+
+    opts = parameters_multi(args[1:])
+    usrs_opts: dict[str, list[str]] = {m.group(1): v for k, v in opts.items() if (m := match(r"users\.(.+)", k))}
+    subs_opts: dict[str, list[str]] = {m.group(1): v for k, v in opts.items() if (m := match(r"submissions\.(.+)", k))}
+    jrns_opts: dict[str, list[str]] = {m.group(1): v for k, v in opts.items() if (m := match(r"journals\.(.+)", k))}
+
+    with FADatabase(args[0]) as db2:
+        print(f"{'Merging with database' if merge else 'Copying entries to'} {db2.database_path}...")
+        cursors: list[FADatabaseCursor] = []
+        cursors.append((db2 if merge else db).users.select(usrs_opts, like=True)) if usrs_opts else None
+        cursors.append((db2 if merge else db).submissions.select(subs_opts, like=True)) if subs_opts else None
+        cursors.append((db2 if merge else db).journals.select(jrns_opts, like=True)) if jrns_opts else None
+        db.merge(db2, *cursors) if merge else db.copy(db2, *cursors)
+        db.commit()
+        print("Done")
+
+
 def database_merge(db: FADatabase, *args: str):
     """
     USAGE
-        falocalrepo database merge <path>
+        falocalrepo database merge <path> [<table1>.<param1>=<value1> ...
+                    <tableN>.<paramN>=<valueN>]
 
     ARGUMENTS
         <path>  Path to second database file
+        <table> One of users, submissions, journals
+        <param> Search parameter
+        <value> Value of the parameter
 
     DESCRIPTION
-        Merge (or create) the database in the current folder with a second database
-        located at 'path'.
+        Merge selected entries from a second database to the main database (the one
+        opened with the program). To select entries, use the same parameters as the
+        search commands precede by a table name. Search parameters can be passed
+        multiple times to act as OR values. All columns of the entries table are
+        supported. Parameters can be lowercase. If no parameters are passed then all
+        the database entries are copied. If submissions entries are selected, their
+        files are copied to the files' folder of the main database.
 
     EXAMPLES
-        falocalrepo database merge ~/Documents/FA/FA.db
+        falocalrepo database merge ~/Documents/FA.backup/A/FA.db users.username=a% \\
+            submissions.author=a% journals.author=a%
+        falocalrepo database merge ~/Documents/FA2020/FA.db \\
+            submissions.date=2020-% journals.date=2020-%
+        falocalrepo database merge ~/Documents/FA.backup/FA.db
     """
 
-    if len(args) != 1:
-        raise MalformedCommand("merge needs one argument")
-    elif not isfile(args[0]):
-        raise FileNotFoundError(f"No such file or directory: '{args[0]}'")
-    with FADatabase(args[0]) as db2:
-        print(f"Merging with database {db2.database_path}...")
-        db.merge(db2)
-        db.commit()
-        print("Done")
+    database_merge_copy(db, True, *args)
+
+
+def database_copy(db: FADatabase, *args: str):
+    """
+    USAGE
+        falocalrepo database copy <path> [<table1>.<param1>=<value1> ...
+                    <tableN>.<paramN>=<valueN>]
+
+    ARGUMENTS
+        <path>  Path to second database file
+        <table> One of users, submissions, journals
+        <param> Search parameter
+        <value> Value of the parameter
+
+    DESCRIPTION
+        Copy selected entries to a new or existing database. To select entries, use
+        the same parameters as the search commands precede by a table name. Search
+        parameters can be passed multiple times to act as OR values. All columns of
+        the entries table are supported. Parameters can be lowercase. If no
+        parameters are passed then all the database entries are copied. If
+        submissions entries are selected, their files are copied to the files'
+        folder of the target database.
+
+    EXAMPLES
+        falocalrepo database copy ~/Documents/FA.backup/A/FA.db users.username=a% \\
+            submissions.author=a% journals.author=a%
+        falocalrepo database copy ~/Documents/FA2020/FA.db submissions.date=2020-% \\
+            journals.date=2020-%
+        falocalrepo database copy ~/Documents/FA.backup/FA.db
+    """
+
+    database_merge_copy(db, False, *args)
 
 
 def database_clean(db: FADatabase, *_rest):
@@ -807,7 +846,7 @@ def database_upgrade(db: FADatabase, *_rest):
     db.upgrade()
 
 
-@docstring_parameter(f"https://pypi.org/project/falocalrepo-database/{__database_version__}")
+@docstring_parameter(__database_version__)
 def database(db: FADatabase, comm: str = "", *args: str):
     """
     USAGE
@@ -832,31 +871,29 @@ def database(db: FADatabase, comm: str = "", *args: str):
         remove-journals     Remove submissions from database
         server              Start local server to browse database
         merge               Merge with a second database
+        copy                Copy entries to a second database
         clean               Clean the database with the VACUUM function
         upgrade             Upgrade the database to the latest version.
 
     DESCRIPTION
-        The database command allows to operate on the database. Used without an
-        operation command shows the database information, statistics (number of
-        users and submissions and time of last update), and version. For more
-        details on tables see {0}.
+        The database command allows to operate on the database. Calling the database
+        command without an operation defaults to 'list'. For more details on tables
+        see https://pypi.org/project/falocalrepo-database/{0}.
 
         All search operations are conducted case-insensitively using the SQLite like
         expression which allows for limited pattern matching. For example this
         expression can be used to search two words together separated by an unknown
         amount of characters '%cat%mouse%'. Fields missing wildcards will only match
-        an exact result, i.e. 'cat' will only match a field equal to 'cat' tag
-        whereas '%cat%' wil match a field that has contains 'cat'. Bars ('|') can be
-        used to isolate individual items in list fields.
+        an exact result, i.e. 'cat' will only match a field equal to 'cat' whereas
+        '%cat%' wil match a field that contains 'cat'. Bars ('|') can be used to
+        isolate individual items in list fields.
 
         All search operations support the extra 'order', 'limit', and 'offset'
-        parameters with values in SQLite 'ORDER BY' clause, 'LIMIT' clause format,
-        and 'OFFSET' clause. The 'order' parameter supports all fields of the
-        specific search command.
+        parameters with values in SQLite 'ORDER BY', 'LIMIT', and 'OFFSET' clause
+        formats. The 'order' parameter supports all fields of the searched table.
     """
 
-    if comm not in ("", "info", "upgrade"):
-        check_database(db.version, __database_version__)
+    check_database_version(db, raise_for_error=comm not in ("", "info", "upgrade"))
 
     {
         "": database_info,
@@ -873,6 +910,7 @@ def database(db: FADatabase, comm: str = "", *args: str):
         "remove-journals": database_remove_journals,
         "server": database_server,
         "merge": database_merge,
+        "copy": database_copy,
         "clean": database_clean,
         "upgrade": database_upgrade,
     }.get(comm, raiser(UnknownCommand(f"database {comm}")))(db, *args)
@@ -938,8 +976,6 @@ def console(comm: str = "", *args: str) -> None:
         return
     elif comm not in (init.__name__, config.__name__, download.__name__, database.__name__):
         raise UnknownCommand(comm)
-    elif check_process(p := "falocalrepo") > 1:
-        raise MultipleInstances(f"Another instance of {p} was detected")
 
     if environ.get("FALOCALREPO_DEBUG", None) is not None:
         print(f"Using FALOCALREPO_DEBUG", file=stderr)
@@ -951,7 +987,8 @@ def console(comm: str = "", *args: str) -> None:
         print(f"Using FALOCALREPO_DATABASE: {db_path}", file=stderr)
         database_path = db_path if db_path.endswith(".db") else join(db_path, database_path)
 
-    db: FADatabase = FADatabase(abspath(database_path))
+    db: FADatabase = FADatabase(database_path)
+    check_database_connections(db)
 
     try:
         db.settings.add_history(f"{comm} {' '.join(args)}".strip())
